==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/P2SetFactory.h <==
// public abstract class soot.jimple.spark.sets.P2SetFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_P2SetFactory_H_
#define _JC_soot_jimple_spark_sets_P2SetFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	_jc_soot_jimple_spark_sets_P2SetFactory$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	_jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$refs	_jc_soot_jimple_spark_sets_P2SetFactory$refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$nonrefs	_jc_soot_jimple_spark_sets_P2SetFactory$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$object	_jc_soot_jimple_spark_sets_P2SetFactory$object;

typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vmethods	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable	_jc_soot_jimple_spark_sets_P2SetFactory$vtable;
typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vtype	_jc_soot_jimple_spark_sets_P2SetFactory$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *);

// Virtual methods
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_P2SetFactory$vmethods {
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*newSet$774f6a02bfa5ba98)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods	soot_jimple_spark_sets_P2SetFactory;
};

// Vtype
struct _jc_soot_jimple_spark_sets_P2SetFactory$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_P2SetFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetFactory$refs {
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	soot_jimple_spark_sets_P2SetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	soot_jimple_spark_sets_P2SetFactory;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_P2SetFactory$object {
	_jc_soot_jimple_spark_sets_P2SetFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_P2SetFactory$vtype	*vtype;
	_jc_soot_jimple_spark_sets_P2SetFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_P2SetFactory$vtype _jc_soot_jimple_spark_sets_P2SetFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_P2SetFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_P2SetFactory$class_object;

#endif	/* _JC_soot_jimple_spark_sets_P2SetFactory_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/P2SetFactory.h <==
// public abstract class soot.jimple.spark.sets.P2SetFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_P2SetFactory_H_
#define _JC_soot_jimple_spark_sets_P2SetFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	_jc_soot_jimple_spark_sets_P2SetFactory$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	_jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$refs	_jc_soot_jimple_spark_sets_P2SetFactory$refs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$nonrefs	_jc_soot_jimple_spark_sets_P2SetFactory$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_P2SetFactory$object	_jc_soot_jimple_spark_sets_P2SetFactory$object;

typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vmethods	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable	_jc_soot_jimple_spark_sets_P2SetFactory$vtable;
typedef const struct _jc_soot_jimple_spark_sets_P2SetFactory$vtype	_jc_soot_jimple_spark_sets_P2SetFactory$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_P2SetFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_sets_P2SetFactory$method$newSet$774f6a02bfa5ba98(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_P2SetFactory$method_info$newSet$774f6a02bfa5ba98;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_P2SetFactory$vmethods {
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*newSet$774f6a02bfa5ba98)(_jc_env *, struct _jc_soot_jimple_spark_sets_P2SetFactory$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_P2SetFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods	soot_jimple_spark_sets_P2SetFactory;
};

// Vtype
struct _jc_soot_jimple_spark_sets_P2SetFactory$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_P2SetFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetFactory$refs {
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	soot_jimple_spark_sets_P2SetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_P2SetFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	soot_jimple_spark_sets_P2SetFactory;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_P2SetFactory$object {
	_jc_soot_jimple_spark_sets_P2SetFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_P2SetFactory$vtype	*vtype;
	_jc_soot_jimple_spark_sets_P2SetFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_P2SetFactory$vtype _jc_soot_jimple_spark_sets_P2SetFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_P2SetFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_P2SetFactory$class_object;

#endif	/* _JC_soot_jimple_spark_sets_P2SetFactory_H_ */
